@@ -20,7 +20,6 @@ Class for tests
 
 use Test::Class;
 use WebDAO::Test;
-use WebDAO::Store::Abstract;
 use WebDAO::SessionSH;
 use WebDAO::Engine;
 use Test::More;
@@ -36,13 +35,12 @@ sub SKIP_CLASS {
     return 1 if $class eq __PACKAGE__;
 }
 
-sub setup : Test(setup=>2) {
+sub setup : Test(setup=>1) {
     my $t = shift;
-    ok( ( my $store_ab = new WebDAO::Store::Abstract:: ), "Create store" );
     my $buffer='';
     $t->{OUT}=\$buffer;
     my $cv = new  TestCV:: \$buffer;
-    ok( ( my $session = new WebDAO::SessionSH:: store => $store_ab, cv=>$cv ),
+    ok( ( my $session = new WebDAO::SessionSH:: cv=>$cv ),
         "Create session" );
     $session->U_id("sdsd");
     my $eng = new WebDAO::Engine:: session => $session;
